# azurerm - library for easy Azure Resource Manager calls from Python

from .adalfns import *
from .amsrp import *
from .computerp import *
from .deployments import *
from .insightsrp import *
from .networkrp import *
from .resourcegroups import *
from .storagerp import *
from .subfns import *
from .templates import *
from .vmimages import *
