# settings.py - place to store constants for azurerm

azure_rm_endpoint = 'https://management.chinacloudapi.cn'

BASE_API = '2016-06-01'
COMP_API = '2017-03-30'
INSIGHTS_API = '2015-07-01'
INSIGHTS_PREVIEW_API = '2016-06-01'
MEDIA_API = '2015-10-01'
NETWORK_API = '2017-04-01'
STORAGE_API = '2016-01-01'
